# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import enum
import typing
import uuid as _uuid

import winrt.system
from winrt._winrt_windows_ui_xaml import (
    CornerRadius,
    Duration,
    GridLength,
    Thickness,
    AdaptiveTrigger,
    Application,
    ApplicationInitializationCallbackParams,
    BindingFailedEventArgs,
    BringIntoViewOptions,
    BringIntoViewRequestedEventArgs,
    BrushTransition,
    ColorPaletteResources,
    CornerRadiusHelper,
    DataContextChangedEventArgs,
    DataTemplate,
    DataTemplateKey,
    DebugSettings,
    DependencyObject,
    DependencyObjectCollection,
    DependencyProperty,
    DependencyPropertyChangedEventArgs,
    DispatcherTimer,
    DragEventArgs,
    DragOperationDeferral,
    DragStartingEventArgs,
    DragUI,
    DragUIOverride,
    DropCompletedEventArgs,
    DurationHelper,
    EffectiveViewportChangedEventArgs,
    ElementFactoryGetArgs,
    ElementFactoryRecycleArgs,
    ElementSoundPlayer,
    EventTrigger,
    ExceptionRoutedEventArgs,
    FrameworkElement,
    FrameworkTemplate,
    FrameworkView,
    FrameworkViewSource,
    GridLengthHelper,
    MediaFailedRoutedEventArgs,
    PointHelper,
    PropertyMetadata,
    PropertyPath,
    RectHelper,
    ResourceDictionary,
    RoutedEvent,
    RoutedEventArgs,
    ScalarTransition,
    Setter,
    SetterBase,
    SetterBaseCollection,
    SizeChangedEventArgs,
    SizeHelper,
    StateTrigger,
    StateTriggerBase,
    Style,
    TargetPropertyPath,
    ThicknessHelper,
    TriggerAction,
    TriggerActionCollection,
    TriggerBase,
    TriggerCollection,
    UIElement,
    UIElementWeakCollection,
    UnhandledExceptionEventArgs,
    Vector3Transition,
    VisualState,
    VisualStateChangedEventArgs,
    VisualStateGroup,
    VisualStateManager,
    VisualTransition,
    Window,
    WindowCreatedEventArgs,
    XamlRoot,
    XamlRootChangedEventArgs,
    _IDataTemplateExtension,
    IDataTemplateExtension,
    _IElementFactory,
    IElementFactory,
)
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from winrt._winrt_windows_ui_xaml import (
        AdaptiveTrigger_Static,
        Application_Static,
        BrushTransition_Static,
        ColorPaletteResources_Static,
        DataTemplate_Static,
        DataTemplateKey_Static,
        DependencyObject_Static,
        DependencyObjectCollection_Static,
        DispatcherTimer_Static,
        ElementFactoryGetArgs_Static,
        ElementFactoryRecycleArgs_Static,
        ExceptionRoutedEventArgs_Static,
        FrameworkElement_Static,
        FrameworkTemplate_Static,
        PropertyMetadata_Static,
        ResourceDictionary_Static,
        RoutedEventArgs_Static,
        ScalarTransition_Static,
        SetterBase_Static,
        StateTriggerBase_Static,
        TriggerAction_Static,
        TriggerBase_Static,
        UIElement_Static,
        UIElementWeakCollection_Static,
        Vector3Transition_Static,
        VisualStateManager_Static,
        VisualTransition_Static,
    )

if typing.TYPE_CHECKING:
    import winrt.windows.applicationmodel as windows_applicationmodel
    import winrt.windows.ui.core as windows_ui_core

__all__ = [
    "ApplicationHighContrastAdjustment",
    "ApplicationRequiresPointerMode",
    "ApplicationTheme",
    "AutomationTextAttributesEnum",
    "DurationType",
    "ElementHighContrastAdjustment",
    "ElementSoundKind",
    "ElementSoundMode",
    "ElementSoundPlayerState",
    "ElementSpatialAudioMode",
    "ElementTheme",
    "FlowDirection",
    "FocusState",
    "FocusVisualKind",
    "FontCapitals",
    "FontEastAsianLanguage",
    "FontEastAsianWidths",
    "FontFraction",
    "FontNumeralAlignment",
    "FontNumeralStyle",
    "FontVariants",
    "GridUnitType",
    "HorizontalAlignment",
    "LineStackingStrategy",
    "OpticalMarginAlignment",
    "TextAlignment",
    "TextLineBounds",
    "TextReadingOrder",
    "TextTrimming",
    "TextWrapping",
    "Vector3TransitionComponents",
    "VerticalAlignment",
    "Visibility",
    "CornerRadius",
    "Duration",
    "GridLength",
    "Thickness",
    "AdaptiveTrigger",
    "Application",
    "ApplicationInitializationCallbackParams",
    "BindingFailedEventArgs",
    "BringIntoViewOptions",
    "BringIntoViewRequestedEventArgs",
    "BrushTransition",
    "ColorPaletteResources",
    "CornerRadiusHelper",
    "DataContextChangedEventArgs",
    "DataTemplate",
    "DataTemplateKey",
    "DebugSettings",
    "DependencyObject",
    "DependencyObjectCollection",
    "DependencyProperty",
    "DependencyPropertyChangedEventArgs",
    "DispatcherTimer",
    "DragEventArgs",
    "DragOperationDeferral",
    "DragStartingEventArgs",
    "DragUI",
    "DragUIOverride",
    "DropCompletedEventArgs",
    "DurationHelper",
    "EffectiveViewportChangedEventArgs",
    "ElementFactoryGetArgs",
    "ElementFactoryRecycleArgs",
    "ElementSoundPlayer",
    "EventTrigger",
    "ExceptionRoutedEventArgs",
    "FrameworkElement",
    "FrameworkTemplate",
    "FrameworkView",
    "FrameworkViewSource",
    "GridLengthHelper",
    "MediaFailedRoutedEventArgs",
    "PointHelper",
    "PropertyMetadata",
    "PropertyPath",
    "RectHelper",
    "ResourceDictionary",
    "RoutedEvent",
    "RoutedEventArgs",
    "ScalarTransition",
    "Setter",
    "SetterBase",
    "SetterBaseCollection",
    "SizeChangedEventArgs",
    "SizeHelper",
    "StateTrigger",
    "StateTriggerBase",
    "Style",
    "TargetPropertyPath",
    "ThicknessHelper",
    "TriggerAction",
    "TriggerActionCollection",
    "TriggerBase",
    "TriggerCollection",
    "UIElement",
    "UIElementWeakCollection",
    "UnhandledExceptionEventArgs",
    "Vector3Transition",
    "VisualState",
    "VisualStateChangedEventArgs",
    "VisualStateGroup",
    "VisualStateManager",
    "VisualTransition",
    "Window",
    "WindowCreatedEventArgs",
    "XamlRoot",
    "XamlRootChangedEventArgs",
    "IDataTemplateExtension",
    "IElementFactory",
    "ApplicationInitializationCallback",
    "BindingFailedEventHandler",
    "CreateDefaultValueCallback",
    "DependencyPropertyChangedCallback",
    "DependencyPropertyChangedEventHandler",
    "DragEventHandler",
    "EnteredBackgroundEventHandler",
    "ExceptionRoutedEventHandler",
    "LeavingBackgroundEventHandler",
    "PropertyChangedCallback",
    "RoutedEventHandler",
    "SizeChangedEventHandler",
    "SuspendingEventHandler",
    "UnhandledExceptionEventHandler",
    "VisualStateChangedEventHandler",
    "WindowActivatedEventHandler",
    "WindowClosedEventHandler",
    "WindowSizeChangedEventHandler",
    "WindowVisibilityChangedEventHandler",
]

class ApplicationHighContrastAdjustment(enum.IntFlag):
    NONE = 0x0
    AUTO = 0xFFFFFFFF

class ApplicationRequiresPointerMode(enum.IntEnum):
    AUTO = 0
    WHEN_REQUESTED = 1

class ApplicationTheme(enum.IntEnum):
    LIGHT = 0
    DARK = 1

class AutomationTextAttributesEnum(enum.IntEnum):
    ANIMATION_STYLE_ATTRIBUTE = 40000
    BACKGROUND_COLOR_ATTRIBUTE = 40001
    BULLET_STYLE_ATTRIBUTE = 40002
    CAP_STYLE_ATTRIBUTE = 40003
    CULTURE_ATTRIBUTE = 40004
    FONT_NAME_ATTRIBUTE = 40005
    FONT_SIZE_ATTRIBUTE = 40006
    FONT_WEIGHT_ATTRIBUTE = 40007
    FOREGROUND_COLOR_ATTRIBUTE = 40008
    HORIZONTAL_TEXT_ALIGNMENT_ATTRIBUTE = 40009
    INDENTATION_FIRST_LINE_ATTRIBUTE = 40010
    INDENTATION_LEADING_ATTRIBUTE = 40011
    INDENTATION_TRAILING_ATTRIBUTE = 40012
    IS_HIDDEN_ATTRIBUTE = 40013
    IS_ITALIC_ATTRIBUTE = 40014
    IS_READ_ONLY_ATTRIBUTE = 40015
    IS_SUBSCRIPT_ATTRIBUTE = 40016
    IS_SUPERSCRIPT_ATTRIBUTE = 40017
    MARGIN_BOTTOM_ATTRIBUTE = 40018
    MARGIN_LEADING_ATTRIBUTE = 40019
    MARGIN_TOP_ATTRIBUTE = 40020
    MARGIN_TRAILING_ATTRIBUTE = 40021
    OUTLINE_STYLES_ATTRIBUTE = 40022
    OVERLINE_COLOR_ATTRIBUTE = 40023
    OVERLINE_STYLE_ATTRIBUTE = 40024
    STRIKETHROUGH_COLOR_ATTRIBUTE = 40025
    STRIKETHROUGH_STYLE_ATTRIBUTE = 40026
    TABS_ATTRIBUTE = 40027
    TEXT_FLOW_DIRECTIONS_ATTRIBUTE = 40028
    UNDERLINE_COLOR_ATTRIBUTE = 40029
    UNDERLINE_STYLE_ATTRIBUTE = 40030
    ANNOTATION_TYPES_ATTRIBUTE = 40031
    ANNOTATION_OBJECTS_ATTRIBUTE = 40032
    STYLE_NAME_ATTRIBUTE = 40033
    STYLE_ID_ATTRIBUTE = 40034
    LINK_ATTRIBUTE = 40035
    IS_ACTIVE_ATTRIBUTE = 40036
    SELECTION_ACTIVE_END_ATTRIBUTE = 40037
    CARET_POSITION_ATTRIBUTE = 40038
    CARET_BIDI_MODE_ATTRIBUTE = 40039

class DurationType(enum.IntEnum):
    AUTOMATIC = 0
    TIME_SPAN = 1
    FOREVER = 2

class ElementHighContrastAdjustment(enum.IntFlag):
    NONE = 0x0
    APPLICATION = 0x80000000
    AUTO = 0xFFFFFFFF

class ElementSoundKind(enum.IntEnum):
    FOCUS = 0
    INVOKE = 1
    SHOW = 2
    HIDE = 3
    MOVE_PREVIOUS = 4
    MOVE_NEXT = 5
    GO_BACK = 6

class ElementSoundMode(enum.IntEnum):
    DEFAULT = 0
    FOCUS_ONLY = 1
    OFF = 2

class ElementSoundPlayerState(enum.IntEnum):
    AUTO = 0
    OFF = 1
    ON = 2

class ElementSpatialAudioMode(enum.IntEnum):
    AUTO = 0
    OFF = 1
    ON = 2

class ElementTheme(enum.IntEnum):
    DEFAULT = 0
    LIGHT = 1
    DARK = 2

class FlowDirection(enum.IntEnum):
    LEFT_TO_RIGHT = 0
    RIGHT_TO_LEFT = 1

class FocusState(enum.IntEnum):
    UNFOCUSED = 0
    POINTER = 1
    KEYBOARD = 2
    PROGRAMMATIC = 3

class FocusVisualKind(enum.IntEnum):
    DOTTED_LINE = 0
    HIGH_VISIBILITY = 1
    REVEAL = 2

class FontCapitals(enum.IntEnum):
    NORMAL = 0
    ALL_SMALL_CAPS = 1
    SMALL_CAPS = 2
    ALL_PETITE_CAPS = 3
    PETITE_CAPS = 4
    UNICASE = 5
    TITLING = 6

class FontEastAsianLanguage(enum.IntEnum):
    NORMAL = 0
    HOJO_KANJI = 1
    JIS04 = 2
    JIS78 = 3
    JIS83 = 4
    JIS90 = 5
    NLC_KANJI = 6
    SIMPLIFIED = 7
    TRADITIONAL = 8
    TRADITIONAL_NAMES = 9

class FontEastAsianWidths(enum.IntEnum):
    NORMAL = 0
    FULL = 1
    HALF = 2
    PROPORTIONAL = 3
    QUARTER = 4
    THIRD = 5

class FontFraction(enum.IntEnum):
    NORMAL = 0
    STACKED = 1
    SLASHED = 2

class FontNumeralAlignment(enum.IntEnum):
    NORMAL = 0
    PROPORTIONAL = 1
    TABULAR = 2

class FontNumeralStyle(enum.IntEnum):
    NORMAL = 0
    LINING = 1
    OLD_STYLE = 2

class FontVariants(enum.IntEnum):
    NORMAL = 0
    SUPERSCRIPT = 1
    SUBSCRIPT = 2
    ORDINAL = 3
    INFERIOR = 4
    RUBY = 5

class GridUnitType(enum.IntEnum):
    AUTO = 0
    PIXEL = 1
    STAR = 2

class HorizontalAlignment(enum.IntEnum):
    LEFT = 0
    CENTER = 1
    RIGHT = 2
    STRETCH = 3

class LineStackingStrategy(enum.IntEnum):
    MAX_HEIGHT = 0
    BLOCK_LINE_HEIGHT = 1
    BASELINE_TO_BASELINE = 2

class OpticalMarginAlignment(enum.IntEnum):
    NONE = 0
    TRIM_SIDE_BEARINGS = 1

class TextAlignment(enum.IntEnum):
    CENTER = 0
    LEFT = 1
    START = 1
    RIGHT = 2
    END = 2
    JUSTIFY = 3
    DETECT_FROM_CONTENT = 4

class TextLineBounds(enum.IntEnum):
    FULL = 0
    TRIM_TO_CAP_HEIGHT = 1
    TRIM_TO_BASELINE = 2
    TIGHT = 3

class TextReadingOrder(enum.IntEnum):
    DEFAULT = 0
    USE_FLOW_DIRECTION = 0
    DETECT_FROM_CONTENT = 1

class TextTrimming(enum.IntEnum):
    NONE = 0
    CHARACTER_ELLIPSIS = 1
    WORD_ELLIPSIS = 2
    CLIP = 3

class TextWrapping(enum.IntEnum):
    NO_WRAP = 1
    WRAP = 2
    WRAP_WHOLE_WORDS = 3

class Vector3TransitionComponents(enum.IntFlag):
    X = 0x1
    Y = 0x2
    Z = 0x4

class VerticalAlignment(enum.IntEnum):
    TOP = 0
    CENTER = 1
    BOTTOM = 2
    STRETCH = 3

class Visibility(enum.IntEnum):
    VISIBLE = 0
    COLLAPSED = 1

winrt.system._mixin_mutable_sequence(DependencyObjectCollection)
winrt.system._mixin_mutable_mapping(ResourceDictionary)
winrt.system._mixin_mutable_sequence(SetterBaseCollection)
winrt.system._mixin_mutable_sequence(TriggerActionCollection)
winrt.system._mixin_mutable_sequence(TriggerCollection)
winrt.system._mixin_mutable_sequence(UIElementWeakCollection)
ApplicationInitializationCallback = typing.Callable[[ApplicationInitializationCallbackParams], None]
BindingFailedEventHandler = typing.Callable[[winrt.system.Object, BindingFailedEventArgs], None]
CreateDefaultValueCallback = typing.Callable[[], winrt.system.Object]
DependencyPropertyChangedCallback = typing.Callable[[DependencyObject, DependencyProperty], None]
DependencyPropertyChangedEventHandler = typing.Callable[[winrt.system.Object, DependencyPropertyChangedEventArgs], None]
DragEventHandler = typing.Callable[[winrt.system.Object, DragEventArgs], None]
EnteredBackgroundEventHandler = typing.Callable[[winrt.system.Object, "windows_applicationmodel.EnteredBackgroundEventArgs"], None]
ExceptionRoutedEventHandler = typing.Callable[[winrt.system.Object, ExceptionRoutedEventArgs], None]
LeavingBackgroundEventHandler = typing.Callable[[winrt.system.Object, "windows_applicationmodel.LeavingBackgroundEventArgs"], None]
PropertyChangedCallback = typing.Callable[[DependencyObject, DependencyPropertyChangedEventArgs], None]
RoutedEventHandler = typing.Callable[[winrt.system.Object, RoutedEventArgs], None]
SizeChangedEventHandler = typing.Callable[[winrt.system.Object, SizeChangedEventArgs], None]
SuspendingEventHandler = typing.Callable[[winrt.system.Object, "windows_applicationmodel.SuspendingEventArgs"], None]
UnhandledExceptionEventHandler = typing.Callable[[winrt.system.Object, UnhandledExceptionEventArgs], None]
VisualStateChangedEventHandler = typing.Callable[[winrt.system.Object, VisualStateChangedEventArgs], None]
WindowActivatedEventHandler = typing.Callable[[winrt.system.Object, "windows_ui_core.WindowActivatedEventArgs"], None]
WindowClosedEventHandler = typing.Callable[[winrt.system.Object, "windows_ui_core.CoreWindowEventArgs"], None]
WindowSizeChangedEventHandler = typing.Callable[[winrt.system.Object, "windows_ui_core.WindowSizeChangedEventArgs"], None]
WindowVisibilityChangedEventHandler = typing.Callable[[winrt.system.Object, "windows_ui_core.VisibilityChangedEventArgs"], None]
